@@ -78,6 +78,7 @@ import com.eteks.sweethome3d.plugin.PluginAction;
 import com.eteks.sweethome3d.plugin.PluginManager;
 import com.eteks.sweethome3d.swing.ControllerAction;
 import com.eteks.sweethome3d.swing.FurnitureTable;
+import com.eteks.sweethome3d.swing.FurnitureTablePanel;
 import com.eteks.sweethome3d.swing.IconManager;
 import com.eteks.sweethome3d.swing.ResourceAction;
 import com.eteks.sweethome3d.swing.SwingTools;
@@ -92,7 +93,7 @@ import com.eteks.sweethome3d.viewcontroller.View;
 import com.eteks.sweethome3d.viewcontroller.ViewFactory;
 
 /**
- * An application wrapper working in applet. 
+ * An application wrapper working in applet.
  * @author Emmanuel Puybaret
  */
 public class AppletApplication extends HomeApplication {
@@ -119,7 +120,7 @@ public class AppletApplication extends HomeApplication {
   private static final String ENABLE_CREATE_VIDEO                    = "enableCreateVideo";
   private static final String SHOW_MEMORY_STATUS_PARAMETER           = "showMemoryStatus";
   private static final String USER_LANGUAGE                          = "userLanguage";
-  
+
   private JApplet         applet;
   private final String    name;
   private HomeRecorder    homeRecorder;
@@ -136,41 +137,41 @@ public class AppletApplication extends HomeApplication {
     } else {
       this.name = applet.getName();
     }
-    
+
     final String readHomeURL = getAppletParameter(applet, READ_HOME_URL_PARAMETER, "readHome.php?home=%s");
-    final String defaultHome = getAppletParameter(applet, DEFAULT_HOME_PARAMETER, "");    
+    final String defaultHome = getAppletParameter(applet, DEFAULT_HOME_PARAMETER, "");
     final boolean showMemoryStatus = getAppletBooleanParameter(applet, SHOW_MEMORY_STATUS_PARAMETER);
 
     URL codeBase = applet.getCodeBase();
 
     try {
-      // Use DnD management without transfer handler under Plugin 2 / Mac OS X, Oracle Java / Mac OS X or OpenJDK / Linux 
+      // Use DnD management without transfer handler under Plugin 2 / Mac OS X, Oracle Java / Mac OS X or OpenJDK / Linux
       boolean plugin2 = applet.getAppletContext() != null
                      && applet.getAppletContext().getClass().getName().startsWith("sun.plugin2.applet.Plugin2Manager");
-      if (OperatingSystem.isMacOSX() && (plugin2 || OperatingSystem.isJavaVersionGreaterOrEqual("1.7")) 
+      if (OperatingSystem.isMacOSX() && (plugin2 || OperatingSystem.isJavaVersionGreaterOrEqual("1.7"))
           || OperatingSystem.isLinux() && System.getProperty("java.runtime.name", "").startsWith("OpenJDK")) {
         System.setProperty("com.eteks.sweethome3d.dragAndDropWithoutTransferHandler", "true");
       }
     } catch (AccessControlException ex) {
       // Unsigned applet
     }
-    
-    checkJavaWebStartBasicService(applet, codeBase);          
- 
+
+    checkJavaWebStartBasicService(applet, codeBase);
+
     initLookAndFeel();
-   
-    // Add a listener that changes the content pane of the current active applet 
+
+    // Add a listener that changes the content pane of the current active applet
     // when a home is added to application
     addHomesListener(new CollectionListener<Home>() {
         private boolean firstHome = true;
-        
+
         public void collectionChanged(CollectionEvent<Home> ev) {
           Home home = ev.getItem();
           switch (ev.getType()) {
             case ADD :
               try {
                 final HomeController controller = createHomeController(home);
-                // Change applet content 
+                // Change applet content
                 applet.setContentPane((JComponent)controller.getView());
                 applet.getRootPane().revalidate();
 
@@ -196,21 +197,21 @@ public class AppletApplication extends HomeApplication {
       });
 
     addComponent3DRenderingErrorObserver();
-    
+
     EventQueue.invokeLater(new Runnable() {
         public void run() {
-          // Create a home in Event Dispatch Thread 
+          // Create a home in Event Dispatch Thread
           addHome(createHome());
-          
+
           if (showMemoryStatus) {
             final String memoryStatus = getUserPreferences().getLocalizedString(AppletApplication.class, "memoryStatus");
-            // Launch a timer that displays memory used by the applet 
+            // Launch a timer that displays memory used by the applet
             memoryStatusTimer = new Timer(1000, new ActionListener() {
                 public void actionPerformed(ActionEvent ev) {
                   Component focusOwner = KeyboardFocusManager.getCurrentKeyboardFocusManager().getFocusOwner();
                   if (focusOwner != null && SwingUtilities.isDescendingFrom(focusOwner, applet)) {
                     Runtime runtime = Runtime.getRuntime();
-                    applet.showStatus(String.format(memoryStatus, 
+                    applet.showStatus(String.format(memoryStatus,
                         Math.round(100f * (runtime.totalMemory() - runtime.freeMemory()) / runtime.maxMemory()),
                         runtime.maxMemory() / 1024 / 1024));
                   }
@@ -224,7 +225,7 @@ public class AppletApplication extends HomeApplication {
 
   /**
    * Deletes open homes and clears all the resources used by this application.
-   * This method is called when an applet is destroyed.  
+   * This method is called when an applet is destroyed.
    */
   public void destroy() {
     if (this.memoryStatusTimer != null) {
@@ -232,21 +233,21 @@ public class AppletApplication extends HomeApplication {
       this.memoryStatusTimer = null;
     }
     for (Home home : getHomes()) {
-      // Delete directly home without closing it because when an applet is destroyed 
-      // we can't control how long a warning dialog about unsaved home will be displayed 
+      // Delete directly home without closing it because when an applet is destroyed
+      // we can't control how long a warning dialog about unsaved home will be displayed
       deleteHome(home);
     }
     // Collect deleted objects (seems to be required under Mac OS X when the applet is being reloaded)
     System.gc();
     try {
-      if (!Boolean.getBoolean("com.eteks.sweethome3d.no3D")) { 
+      if (!Boolean.getBoolean("com.eteks.sweethome3d.no3D")) {
         // Stop managers threads
         TextureManager.getInstance().clear();
         ModelManager.getInstance().clear();
       }
       IconManager.getInstance().clear();
     } catch (AccessControlException ex) {
-      // If com.eteks.sweethome3d.no3D property can't be read, 
+      // If com.eteks.sweethome3d.no3D property can't be read,
       // security manager won't allow to access to Java 3D DLLs required by previous classes too
     }
     // Delete temporary files
@@ -279,12 +280,12 @@ public class AppletApplication extends HomeApplication {
     }
     return urls.toArray(new URL [urls.size()]);
   }
-  
+
   /**
    * Returns the URL object matching the given <code>url</code> eventually relative to <code>codeBase</code>.
    */
   private URL getURLWithCodeBase(URL codeBase, String url) {
-    if (url != null 
+    if (url != null
         && url.length() > 0) {
       try {
         return new URL(codeBase, url);
@@ -294,7 +295,7 @@ public class AppletApplication extends HomeApplication {
     }
     return null;
   }
-  
+
   /**
    * Returns the URL matching the given <code>url</code> eventually relative to <code>codeBase</code>.
    */
@@ -308,9 +309,9 @@ public class AppletApplication extends HomeApplication {
     }
     return null;
   }
-  
+
   /**
-   * Returns the parameter value of the given <code>parameter</code> or 
+   * Returns the parameter value of the given <code>parameter</code> or
    * <code>defaultValue</code> if it doesn't exist.
    */
   private String getAppletParameter(JApplet applet, String parameter, String defaultValue) {
@@ -321,43 +322,43 @@ public class AppletApplication extends HomeApplication {
       return parameterValue;
     }
   }
-  
+
   /**
-   * Returns the parameter value of the given <code>parameter</code> or 
+   * Returns the parameter value of the given <code>parameter</code> or
    * <code>false</code> if it doesn't exist.
    */
   private boolean getAppletBooleanParameter(JApplet applet, String parameter) {
     return "true".equalsIgnoreCase(getAppletParameter(applet, parameter, "false"));
   }
-  
+
   /**
    * Returns a new instance of a home controller after <code>home</code> was created.
    */
   protected HomeController createHomeController(Home home) {
-    final String writeHomeURL = getAppletParameter(this.applet, WRITE_HOME_URL_PARAMETER, "writeHome.php");    
+    final String writeHomeURL = getAppletParameter(this.applet, WRITE_HOME_URL_PARAMETER, "writeHome.php");
     final String readHomeURL = getAppletParameter(this.applet, READ_HOME_URL_PARAMETER, "readHome.php?home=%s");
     final String listHomesURL = getAppletParameter(this.applet, LIST_HOMES_URL_PARAMETER, "listHomes.php");
-    final String defaultHome = getAppletParameter(this.applet, DEFAULT_HOME_PARAMETER, "");    
-    
+    final String defaultHome = getAppletParameter(this.applet, DEFAULT_HOME_PARAMETER, "");
+
     // Create a home controller for new home
-    boolean newHomeEnabled = 
+    boolean newHomeEnabled =
         writeHomeURL.length() != 0 && listHomesURL.length() != 0;
-    boolean openEnabled = 
+    boolean openEnabled =
         readHomeURL.length() != 0 && listHomesURL.length() != 0;
-    boolean saveEnabled = writeHomeURL.length() != 0 
+    boolean saveEnabled = writeHomeURL.length() != 0
         && (defaultHome.length() != 0 || listHomesURL.length() != 0);
-    boolean saveAsEnabled = 
+    boolean saveAsEnabled =
         writeHomeURL.length() != 0 && listHomesURL.length() != 0;
-    long homeMaximumLength = Long.valueOf(getAppletParameter(applet, HOME_MAXIMUM_LENGTH, "-1"));    
-    
+    long homeMaximumLength = Long.valueOf(getAppletParameter(applet, HOME_MAXIMUM_LENGTH, "-1"));
+
     final HomeController controller = new HomeAppletController(
         home, AppletApplication.this, getViewFactory(), getContentManager(), getPluginManager(),
         newHomeEnabled, openEnabled, saveEnabled, saveAsEnabled, homeMaximumLength);
-    
+
     JRootPane homeView = (JRootPane)controller.getView();
     // Remove menu bar
     homeView.setJMenuBar(null);
-    
+
     // As the applet has no menu, activate accelerators directly on home view
     for (HomeView.ActionType actionType : HomeView.ActionType.values()) {
       Action action = homeView.getActionMap().get(actionType);
@@ -369,10 +370,10 @@ public class AppletApplication extends HomeApplication {
         }
       }
     }
-    
+
     // Change default buttons in toolbar
     JToolBar toolBar = (JToolBar)homeView.getContentPane().getComponent(0);
-    toolBar.setFloatable(false);    
+    toolBar.setFloatable(false);
     // Retrieve all buttons that are plug-in actions
     List<JComponent> pluginButtons = new ArrayList<JComponent>();
     for (int i = 0; i < toolBar.getComponentCount(); i++) {
@@ -389,11 +390,11 @@ public class AppletApplication extends HomeApplication {
     addEnabledActionToToolBar(homeView, HomeView.ActionType.OPEN, toolBar);
     addEnabledActionToToolBar(homeView, HomeView.ActionType.SAVE, toolBar);
     addEnabledActionToToolBar(homeView, HomeView.ActionType.SAVE_AS, toolBar);
-    
+
     if (getAppletBooleanParameter(this.applet, ENABLE_EXPORT_TO_SH3D)) {
       try {
         // Add export to SH3D action
-        Action exportToSH3DAction = new ControllerAction(getUserPreferences(), 
+        Action exportToSH3DAction = new ControllerAction(getUserPreferences(),
             AppletApplication.class, "EXPORT_TO_SH3D", controller, "exportToSH3D");
         exportToSH3DAction.setEnabled(true);
         addActionToToolBar(new ResourceAction.ToolBarAction(exportToSH3DAction), toolBar);
@@ -404,7 +405,7 @@ public class AppletApplication extends HomeApplication {
     if (getAppletBooleanParameter(this.applet, ENABLE_IMPORT_FROM_SH3D)) {
       try {
         // Add import from SH3D action
-        Action importFromSH3DAction = new ControllerAction(getUserPreferences(), 
+        Action importFromSH3DAction = new ControllerAction(getUserPreferences(),
             AppletApplication.class, "IMPORT_FROM_SH3D", controller, "importFromSH3D");
         importFromSH3DAction.setEnabled(true);
         addActionToToolBar(new ResourceAction.ToolBarAction(importFromSH3DAction), toolBar);
@@ -412,15 +413,15 @@ public class AppletApplication extends HomeApplication {
         ex.printStackTrace();
       }
     }
-    
+
     if (toolBar.getComponentCount() > 0) {
       toolBar.add(Box.createRigidArea(new Dimension(2, 2)));
     }
     addActionToToolBar(homeView, HomeView.ActionType.PAGE_SETUP, toolBar);
     addActionToToolBar(homeView, HomeView.ActionType.PRINT, toolBar);
     Action printToPdfAction = getToolBarAction(homeView, HomeView.ActionType.PRINT_TO_PDF);
-    if (printToPdfAction != null 
-        && getAppletBooleanParameter(this.applet, ENABLE_PRINT_TO_PDF) 
+    if (printToPdfAction != null
+        && getAppletBooleanParameter(this.applet, ENABLE_PRINT_TO_PDF)
         && !OperatingSystem.isMacOSX()) {
       controller.getView().setEnabled(HomeView.ActionType.PRINT_TO_PDF, true);
       addActionToToolBar(printToPdfAction, toolBar);
@@ -447,15 +448,16 @@ public class AppletApplication extends HomeApplication {
       addActionToToolBar(addHomeFurnitureAction, toolBar);
       toolBar.addSeparator();
     }
-    
+
     addToggleActionToToolBar(homeView, HomeView.ActionType.SELECT, toolBar);
     addToggleActionToToolBar(homeView, HomeView.ActionType.PAN, toolBar);
     addToggleActionToToolBar(homeView, HomeView.ActionType.CREATE_WALLS, toolBar);
     addToggleActionToToolBar(homeView, HomeView.ActionType.CREATE_ROOMS, toolBar);
+    addToggleActionToToolBar(homeView, HomeView.ActionType.CREATE_POLYLINES, toolBar);
     addToggleActionToToolBar(homeView, HomeView.ActionType.CREATE_DIMENSION_LINES, toolBar);
     addToggleActionToToolBar(homeView, HomeView.ActionType.CREATE_LABELS, toolBar);
     toolBar.add(Box.createRigidArea(new Dimension(2, 2)));
-    
+
     addActionToToolBar(homeView, HomeView.ActionType.ZOOM_OUT, toolBar);
     addActionToToolBar(homeView, HomeView.ActionType.ZOOM_IN, toolBar);
 
@@ -463,7 +465,7 @@ public class AppletApplication extends HomeApplication {
     try {
       no3D = Boolean.getBoolean("com.eteks.sweethome3d.no3D");
     } catch (AccessControlException ex) {
-      // If com.eteks.sweethome3d.no3D property can't be read, 
+      // If com.eteks.sweethome3d.no3D property can't be read,
       // security manager won't allow to access to Java 3D DLLs required to manage 3D too
       no3D = true;
     }
@@ -472,7 +474,7 @@ public class AppletApplication extends HomeApplication {
       if (createPhotoAction != null) {
         boolean enableCreatePhoto = getAppletBooleanParameter(this.applet, ENABLE_CREATE_PHOTO);
         controller.getView().setEnabled(HomeView.ActionType.CREATE_PHOTO, enableCreatePhoto);
-        controller.getView().setEnabled(HomeView.ActionType.CREATE_PHOTOS_AT_POINTS_OF_VIEW, 
+        controller.getView().setEnabled(HomeView.ActionType.CREATE_PHOTOS_AT_POINTS_OF_VIEW,
             enableCreatePhoto && !home.getStoredCameras().isEmpty());
         if (enableCreatePhoto) {
           toolBar.addSeparator();
@@ -481,7 +483,7 @@ public class AppletApplication extends HomeApplication {
           // Ensure CREATE_PHOTOS_AT_POINTS_OF_VIEW action will remain disabled even after points of view are created
           homeView.getActionMap().get(HomeView.ActionType.CREATE_PHOTOS_AT_POINTS_OF_VIEW).addPropertyChangeListener(
               new PropertyChangeListener() {
-                public void propertyChange(PropertyChangeEvent ev) {  
+                public void propertyChange(PropertyChangeEvent ev) {
                   if ("enabled".equals(ev.getPropertyName())) {
                     Action action = (Action)ev.getSource();
                     action.removePropertyChangeListener(this);
@@ -501,28 +503,28 @@ public class AppletApplication extends HomeApplication {
         toolBar.add(pluginButton);
       }
     }
-    
+
     Action aboutAction = getToolBarAction(homeView, HomeView.ActionType.ABOUT);
     if (aboutAction != null) {
       toolBar.addSeparator();
       addActionToToolBar(aboutAction, toolBar);
     }
-    
-    controller.getView().setEnabled(HomeView.ActionType.EXPORT_TO_CSV, 
+
+    controller.getView().setEnabled(HomeView.ActionType.EXPORT_TO_CSV,
         getAppletBooleanParameter(this.applet, ENABLE_EXPORT_TO_CSV));
-    controller.getView().setEnabled(HomeView.ActionType.EXPORT_TO_SVG, 
+    controller.getView().setEnabled(HomeView.ActionType.EXPORT_TO_SVG,
         getAppletBooleanParameter(this.applet, ENABLE_EXPORT_TO_SVG));
-    controller.getView().setEnabled(HomeView.ActionType.EXPORT_TO_OBJ, 
+    controller.getView().setEnabled(HomeView.ActionType.EXPORT_TO_OBJ,
         getAppletBooleanParameter(this.applet, ENABLE_EXPORT_TO_OBJ) && !no3D);
-    controller.getView().setEnabled(HomeView.ActionType.CREATE_VIDEO, 
+    controller.getView().setEnabled(HomeView.ActionType.CREATE_VIDEO,
         getAppletBooleanParameter(this.applet, ENABLE_CREATE_VIDEO) && !no3D);
-    
+
     // Add a border
     homeView.setBorder(BorderFactory.createLineBorder(Color.LIGHT_GRAY));
-    
+
     return controller;
   }
-  
+
   /**
    * Adds the action matching the given <code>actionType</code> to the tool bar if it exists and it's enabled.
    */
@@ -532,7 +534,7 @@ public class AppletApplication extends HomeApplication {
       addActionToToolBar(action, toolBar);
     }
   }
-  
+
   /**
    * Adds the action matching the given <code>actionType</code> to the tool bar if it exists.
    */
@@ -547,18 +549,18 @@ public class AppletApplication extends HomeApplication {
    * Returns an action decorated for tool bar buttons.
    */
   private Action getToolBarAction(JComponent homeView, HomeView.ActionType actionType) {
-    Action action = homeView.getActionMap().get(actionType);    
-    return action != null 
+    Action action = homeView.getActionMap().get(actionType);
+    return action != null
         ? new ResourceAction.ToolBarAction(action)
         : null;
   }
-  
+
   /**
    * Adds the given action to the tool bar.
    */
   private void addActionToToolBar(Action action, JToolBar toolBar) {
     if (OperatingSystem.isMacOSXLeopardOrSuperior() && OperatingSystem.isJavaVersionGreaterOrEqual("1.7")) {
-      // Add a button with higher insets to ensure the top and bottom of segmented buttons are correctly drawn 
+      // Add a button with higher insets to ensure the top and bottom of segmented buttons are correctly drawn
       toolBar.add(new JButton(action) {
           @Override
           public Insets getInsets() {
@@ -581,7 +583,7 @@ public class AppletApplication extends HomeApplication {
     if (action != null) {
       JToggleButton toggleButton;
       if (OperatingSystem.isMacOSXLeopardOrSuperior() && OperatingSystem.isJavaVersionGreaterOrEqual("1.7")) {
-        // Use higher insets to ensure the top and bottom of segmented buttons are correctly drawn 
+        // Use higher insets to ensure the top and bottom of segmented buttons are correctly drawn
         toggleButton = new JToggleButton(action) {
             @Override
             public Insets getInsets() {
@@ -606,19 +608,19 @@ public class AppletApplication extends HomeApplication {
   public HomeRecorder getHomeRecorder() {
     if (this.homeRecorder == null) {
       URL codeBase = this.applet.getCodeBase();
-      final String writeHomeURL = getAppletParameter(this.applet, WRITE_HOME_URL_PARAMETER, "writeHome.php");    
+      final String writeHomeURL = getAppletParameter(this.applet, WRITE_HOME_URL_PARAMETER, "writeHome.php");
       final String readHomeURL = getAppletParameter(this.applet, READ_HOME_URL_PARAMETER, "readHome.php?home=%s");
       final String listHomesURL = getAppletParameter(this.applet, LIST_HOMES_URL_PARAMETER, "listHomes.php");
       final String deleteHomeURL = getAppletParameter(this.applet, DELETE_HOME_URL_PARAMETER, "");
-      this.homeRecorder =  new HomeAppletRecorder(getURLStringWithCodeBase(codeBase, writeHomeURL), 
-          getURLStringWithCodeBase(codeBase, readHomeURL), 
+      this.homeRecorder =  new HomeAppletRecorder(getURLStringWithCodeBase(codeBase, writeHomeURL),
+          getURLStringWithCodeBase(codeBase, readHomeURL),
           getURLStringWithCodeBase(codeBase, listHomesURL),
           getURLStringWithCodeBase(codeBase, deleteHomeURL),
           ContentRecording.INCLUDE_TEMPORARY_CONTENT);
     }
     return this.homeRecorder;
   }
-  
+
   /**
    * Returns user preferences.
    */
@@ -631,16 +633,16 @@ public class AppletApplication extends HomeApplication {
       final String furnitureResourcesUrlBase = getAppletParameter(this.applet, FURNITURE_RESOURCES_URL_BASE_PARAMETER, null);
       final String texturesCatalogURLs = getAppletParameter(this.applet, TEXTURES_CATALOG_URLS_PARAMETER, "catalog.zip");
       final String texturesResourcesUrlBase = getAppletParameter(this.applet, TEXTURES_RESOURCES_URL_BASE_PARAMETER, null);
-      final String readPreferencesURL = getAppletParameter(this.applet, READ_PREFERENCES_URL_PARAMETER, "");    
-      final String writePreferencesURL = getAppletParameter(this.applet, WRITE_PREFERENCES_URL_PARAMETER, "");    
-      final String userLanguage = getAppletParameter(this.applet, USER_LANGUAGE, null);    
+      final String readPreferencesURL = getAppletParameter(this.applet, READ_PREFERENCES_URL_PARAMETER, "");
+      final String writePreferencesURL = getAppletParameter(this.applet, WRITE_PREFERENCES_URL_PARAMETER, "");
+      final String userLanguage = getAppletParameter(this.applet, USER_LANGUAGE, null);
       this.userPreferences = new AppletUserPreferences(
-          getURLs(codeBase, furnitureCatalogURLs), 
-          getURLWithCodeBase(codeBase, furnitureResourcesUrlBase), 
+          getURLs(codeBase, furnitureCatalogURLs),
+          getURLWithCodeBase(codeBase, furnitureResourcesUrlBase),
           getURLs(codeBase, texturesCatalogURLs),
-          getURLWithCodeBase(codeBase, texturesResourcesUrlBase), 
-          getURLWithCodeBase(codeBase, writePreferencesURL), 
-          getURLWithCodeBase(codeBase, readPreferencesURL), 
+          getURLWithCodeBase(codeBase, texturesResourcesUrlBase),
+          getURLWithCodeBase(codeBase, writePreferencesURL),
+          getURLWithCodeBase(codeBase, readPreferencesURL),
           new Executor() {
               public void execute(Runnable command) {
                 EventQueue.invokeLater(command);
@@ -660,16 +662,20 @@ public class AppletApplication extends HomeApplication {
     }
     return this.contentManager;
   }
-  
+
   /**
-   * Returns a Swing view factory. 
+   * Returns a Swing view factory.
    */
   protected ViewFactory getViewFactory() {
     if (this.viewFactory == null) {
      this.viewFactory = new SwingViewFactory() {
          @Override
          public View createFurnitureView(Home home, UserPreferences preferences, FurnitureController furnitureController) {
-           return new AppletFurnitureTable(home, preferences, furnitureController);
+           return new FurnitureTablePanel(home, preferences, furnitureController) {
+               protected FurnitureTable createFurnitureTable(Home home, UserPreferences preferences, FurnitureController furnitureController) {
+                 return new AppletFurnitureTable(home, preferences, furnitureController);
+               }
+             };
          }
        };
     }
@@ -677,7 +683,7 @@ public class AppletApplication extends HomeApplication {
   }
 
   /**
-   * Returns the plugin manager of this application. 
+   * Returns the plugin manager of this application.
    */
   protected PluginManager getPluginManager() {
     if (this.pluginManager == null) {
@@ -695,7 +701,7 @@ public class AppletApplication extends HomeApplication {
   public String getName() {
     return this.name;
   }
-  
+
   /**
    * Returns information about the version of this applet application.
    */
@@ -703,7 +709,7 @@ public class AppletApplication extends HomeApplication {
   public String getVersion() {
     return getUserPreferences().getLocalizedString(AppletApplication.class, "applicationVersion");
   }
-  
+
   /**
    * Sets application look and feel.
    */
@@ -713,7 +719,7 @@ public class AppletApplication extends HomeApplication {
       UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
       // Change default titled borders under Mac OS X 10.5
       if (OperatingSystem.isMacOSXLeopardOrSuperior()) {
-        UIManager.put("TitledBorder.border", 
+        UIManager.put("TitledBorder.border",
             UIManager.getBorder("TitledBorder.aquaVariant"));
       }
       // Enable applets to update their content while window resizing
@@ -723,16 +729,16 @@ public class AppletApplication extends HomeApplication {
       // Too bad keep current look and feel
     }
   }
-  
+
   /**
-   * Sets the rendering error listener bound to Java 3D 
-   * to avoid default System exit in case of error during 3D rendering. 
+   * Sets the rendering error listener bound to Java 3D
+   * to avoid default System exit in case of error during 3D rendering.
    */
   private void addComponent3DRenderingErrorObserver() {
     try {
       if (!Boolean.getBoolean("com.eteks.sweethome3d.no3D")) {
-        // Instead of adding a RenderingErrorListener directly to VirtualUniverse, 
-        // we add it through Component3DManager, because offscreen rendering needs to check 
+        // Instead of adding a RenderingErrorListener directly to VirtualUniverse,
+        // we add it through Component3DManager, because offscreen rendering needs to check
         // rendering errors with its own RenderingErrorListener
         Component3DManager.getInstance().setRenderingErrorObserver(
             new Component3DManager.RenderingErrorObserver() {
@@ -747,18 +753,18 @@ public class AppletApplication extends HomeApplication {
             });
       }
     } catch (AccessControlException ex) {
-      // If com.eteks.sweethome3d.no3D property can't be read, 
+      // If com.eteks.sweethome3d.no3D property can't be read,
       // security manager won't allow to access to Java 3D DLLs required by Component3DManager class too
     }
   }
 
   /**
-   * Displays a message to user about a 3D error. 
+   * Displays a message to user about a 3D error.
    */
   private void show3DError() {
     String message = getUserPreferences().getLocalizedString(AppletApplication.class, "3DError.message");
     String title = getUserPreferences().getLocalizedString(AppletApplication.class, "3DError.title");
-    JOptionPane.showMessageDialog(KeyboardFocusManager.getCurrentKeyboardFocusManager().getActiveWindow(), 
+    JOptionPane.showMessageDialog(KeyboardFocusManager.getCurrentKeyboardFocusManager().getActiveWindow(),
         message, title, JOptionPane.ERROR_MESSAGE);
   }
 
@@ -766,9 +772,9 @@ public class AppletApplication extends HomeApplication {
    * Checks whether Java Web Start basic service is available to be able to display document from the applet.
    */
   private void checkJavaWebStartBasicService(final JApplet applet, URL codeBase) {
-    boolean serviceManagerAvailable = ServiceManager.getServiceNames() != null; 
+    boolean serviceManagerAvailable = ServiceManager.getServiceNames() != null;
     if (serviceManagerAvailable) {
-      try { 
+      try {
         ServiceManager.lookup("javax.jnlp.BasicService");
       } catch (Exception ex) {
         if ("javax.jnlp.UnavailableServiceException".equals(ex.getClass().getName())) {
@@ -780,7 +786,7 @@ public class AppletApplication extends HomeApplication {
     }
 
     if (!serviceManagerAvailable) {
-      // Create JNLP services required by Sweet Home 3D 
+      // Create JNLP services required by Sweet Home 3D
       ServiceManager.setServiceManagerStub(
           new StandaloneServiceManager(applet.getAppletContext(), codeBase));
       // Caution: setting a new service manager stub won't replace the existing one
@@ -794,7 +800,7 @@ public class AppletApplication extends HomeApplication {
     private TableCellRenderer nameRenderer = new TableCellRenderer() {
         private Font defaultFont;
         private Font importedPieceFont;
-      
+
         public Component getTableCellRendererComponent(JTable table, Object value, boolean isSelected, boolean hasFocus,
                                                        int row, int column) {
           JComponent rendererComponent = (JComponent)AppletFurnitureTable.super.getCellRenderer(row, column).
@@ -802,10 +808,10 @@ public class AppletApplication extends HomeApplication {
           // Initialize fonts if not done
           if (this.defaultFont == null) {
             this.defaultFont = table.getFont();
-            this.importedPieceFont = 
-                new Font(this.defaultFont.getFontName(), Font.ITALIC, this.defaultFont.getSize());        
+            this.importedPieceFont =
+                new Font(this.defaultFont.getFontName(), Font.ITALIC, this.defaultFont.getSize());
           }
-          
+
           HomePieceOfFurniture piece = (HomePieceOfFurniture)getValueAt(row, column);
           URLContent model = (URLContent)piece.getModel();
           // Imported pieces are not stored in URLContent instances
@@ -831,7 +837,7 @@ public class AppletApplication extends HomeApplication {
   }
 
   /**
-   * JNLP <code>ServiceManagerStub</code> implementation for applets 
+   * JNLP <code>ServiceManagerStub</code> implementation for applets
    * run out of Java Web Start. This service manager supports <code>BasicService</code> only.
    */
   private static class StandaloneServiceManager implements ServiceManagerStub {
@@ -849,11 +855,11 @@ public class AppletApplication extends HomeApplication {
         throw new UnavailableServiceException(name);
       }
     }
-    
+
     public String[] getServiceNames() {
       return new String[]  {"javax.jnlp.BasicService"};
     }
-  }    
+  }
 
   /**
    * <code>BasicService</code> that displays a web page in the current browser.
