@@ -378,8 +378,8 @@ public class TextureManager {
   public float getRotatedTextureWidth(HomeTexture texture) {
     float angle = texture.getAngle();
     if (angle != 0) {
-      return (float)Math.rint(Math.abs(texture.getWidth() * Math.cos(angle)) 
-          + Math.abs(texture.getHeight() * Math.sin(angle)));
+      return (float)(texture.getWidth() * Math.cos(angle) 
+          + texture.getHeight() * Math.sin(angle));
     } else {
       return texture.getWidth();
     }
@@ -391,8 +391,8 @@ public class TextureManager {
   public float getRotatedTextureHeight(HomeTexture texture) {
     float angle = texture.getAngle();
     if (angle != 0) {
-      return (float)Math.rint(Math.abs(texture.getWidth() * Math.sin(angle)) 
-          + Math.abs(texture.getHeight() * Math.cos(angle)));
+      return (float)(texture.getWidth() * Math.sin(angle) 
+          + texture.getHeight() * Math.cos(angle));
     } else {
       return texture.getHeight();
     }
