@@ -52,12 +52,13 @@ import com.eteks.sweethome3d.model.HomePrint;
 import com.eteks.sweethome3d.model.LengthUnit;
 import com.eteks.sweethome3d.model.Level;
 import com.eteks.sweethome3d.viewcontroller.ContentManager;
+import com.eteks.sweethome3d.viewcontroller.FurnitureView;
 import com.eteks.sweethome3d.viewcontroller.HomeController;
 import com.eteks.sweethome3d.viewcontroller.PlanView;
 import com.eteks.sweethome3d.viewcontroller.View;
 
 /**
- * A printable component used to print or preview the furniture, the plan 
+ * A printable component used to print or preview the furniture, the plan
  * and the 3D view of a home.
  */
 public class HomePrintableComponent extends JComponent implements Printable {
@@ -72,30 +73,30 @@ public class HomePrintableComponent extends JComponent implements Printable {
     TIME("$time", "{3, time}"),
     HOME_PRESENTATION_NAME("$name", "{4}"),
     HOME_NAME("$file", "{5}"),
-    LEVEL_NAME("$level", "{6}");    
-    
+    LEVEL_NAME("$level", "{6}");
+
     private final String userCode;
     private final String formatCode;
 
     private Variable(String userCode, String formatCode) {
       this.userCode = userCode;
-      this.formatCode = formatCode;      
+      this.formatCode = formatCode;
     }
-    
+
     /**
      * Returns a user readable code matching this field.
      */
     public String getUserCode() {
       return this.userCode;
     }
-    
+
     /**
      * Returns a format usable code matching this field.
      */
     public String getFormatCode()  {
       return this.formatCode;
     }
-    
+
     /**
      * Returns the message format built from a format that uses variables.
      */
@@ -116,7 +117,7 @@ public class HomePrintableComponent extends JComponent implements Printable {
   };
 
   private static final float   HEADER_FOOTER_MARGIN = LengthUnit.centimeterToInch(0.2f) * 72;
-  
+
   private final Home           home;
   private final HomeController controller;
   private final Font           defaultFont;
@@ -131,10 +132,10 @@ public class HomePrintableComponent extends JComponent implements Printable {
   private JLabel               fixedFooterLabel;
   private JLabel               fixedFirstPageHeaderLabel;
   private JLabel               fixedFirstPageFooterLabel;
-  
+
   /**
    * Creates a printable component that will print or display the
-   * furniture view, the plan view and 3D view of the <code>home</code> 
+   * furniture view, the plan view and 3D view of the <code>home</code>
    * managed by <code>controller</code>.
    */
   public HomePrintableComponent(Home home, HomeController controller, Font defaultFont) {
@@ -142,7 +143,7 @@ public class HomePrintableComponent extends JComponent implements Printable {
     this.controller = controller;
     this.defaultFont = defaultFont;
     this.headerFooterFont = defaultFont.deriveFont(11f);
-    
+
     try {
       ResourceBundle resource = ResourceBundle.getBundle(HomePrintableComponent.class.getName());
       this.fixedHeaderLabel = getFixedHeaderOrFooterLabel(resource, "fixedHeader");
@@ -156,18 +157,18 @@ public class HomePrintableComponent extends JComponent implements Printable {
         this.fixedFirstPageFooterLabel = this.fixedFooterLabel;
       }
     } catch (MissingResourceException ex) {
-      // No resource bundle 
+      // No resource bundle
     }
   }
 
   private JLabel getFixedHeaderOrFooterLabel(ResourceBundle resource, String resourceKey) {
-    try {        
+    try {
       // Build URL base for resources referenced in fixed header or footer
       String classFile = "/" + HomePrintableComponent.class.getName().replace('.', '/') + ".properties";
       String urlBase = HomePrintableComponent.class.getResource(classFile).toString();
-      urlBase = urlBase.substring(0, urlBase.length() - classFile.length());      
-      
-      String fixedHeaderOrFooter = String.format(resource.getString(resourceKey), urlBase);      
+      urlBase = urlBase.substring(0, urlBase.length() - classFile.length());
+
+      String fixedHeaderOrFooter = String.format(resource.getString(resourceKey), urlBase);
       JLabel fixedHeaderOrFooterLabel = new JLabel(fixedHeaderOrFooter, JLabel.CENTER);
       fixedHeaderOrFooterLabel.setFont(this.headerFooterFont);
       fixedHeaderOrFooterLabel.setSize(fixedHeaderOrFooterLabel.getPreferredSize());
@@ -177,7 +178,7 @@ public class HomePrintableComponent extends JComponent implements Printable {
       return null;
     }
   }
-  
+
   /**
    * Prints a given <code>page</code>.
    */
@@ -186,7 +187,7 @@ public class HomePrintableComponent extends JComponent implements Printable {
     if (Thread.interrupted()) {
       throw new InterruptedPrinterException();
     }
-    
+
     Graphics2D g2D = (Graphics2D)g;
     g2D.setFont(this.defaultFont);
     g2D.setColor(Color.WHITE);
@@ -209,7 +210,7 @@ public class HomePrintableComponent extends JComponent implements Printable {
     }
     int pageExists = NO_SUCH_PAGE;
     HomePrint homePrint = this.home.getPrint();
-    
+
     // Prepare header and footer
     float imageableY = (float)pageFormat.getImageableY();
     float imageableHeight = (float)pageFormat.getImageableHeight();
@@ -223,7 +224,7 @@ public class HomePrintableComponent extends JComponent implements Printable {
     float  yFooter = 0;
     float  xFixedFooter = 0;
     float  yFixedFooter = 0;
-    
+
     JLabel fixedHeaderPageLabel = page == 0
         ? this.fixedFirstPageHeaderLabel : this.fixedHeaderLabel;
     JLabel fixedFooterPageLabel = page == 0
@@ -235,14 +236,14 @@ public class HomePrintableComponent extends JComponent implements Printable {
       xFixedHeader = (float)pageFormat.getImageableX();
       yFixedHeader = (float)pageFormat.getImageableY();
     }
-    
+
     if (fixedFooterPageLabel != null) {
       fixedFooterPageLabel.setSize((int)pageFormat.getImageableWidth(), fixedFooterPageLabel.getPreferredSize().height);
       imageableHeight -= fixedFooterPageLabel.getHeight() + HEADER_FOOTER_MARGIN;
       xFixedFooter = (float)pageFormat.getImageableX();
       yFixedFooter = (float)(pageFormat.getImageableY() + pageFormat.getImageableHeight()) - fixedFooterPageLabel.getHeight();
     }
-    
+
     Rectangle clipBounds = g2D.getClipBounds();
     AffineTransform oldTransform = g2D.getTransform();
     final PlanView planView = this.controller.getPlanController().getView();
@@ -252,25 +253,18 @@ public class HomePrintableComponent extends JComponent implements Printable {
       if (homePrint != null) {
         FontMetrics fontMetrics = g2D.getFontMetrics(this.headerFooterFont);
         float headerFooterHeight = fontMetrics.getAscent() + fontMetrics.getDescent() + HEADER_FOOTER_MARGIN;
-        
+
         // Retrieve variable values
-        int pageNumber = page + 1; 
-        int pageCount = getPageCount(); 
+        int pageNumber = page + 1;
+        int pageCount = getPageCount();
         String planScale = "?";
         if (homePrint.getPlanScale() != null) {
           planScale = "1/" + Math.round(1 / homePrint.getPlanScale());
         } else {
-          Float preferredScale = null;
-          // Should create an interface to test if the component has a preferred scale
-          if (planView instanceof PlanComponent) {
-            preferredScale = ((PlanComponent)planView).getPrintPreferredScale(g, pageFormat);
-          } else if (planView instanceof MultipleLevelsPlanPanel) {
-            preferredScale = ((MultipleLevelsPlanPanel)planView).getPrintPreferredScale(g, pageFormat);
-          }     
-          if (preferredScale != null) {
-            planScale = "1/" + Math.round(1 / preferredScale);
-          }
-        }          
+          float preferredScale = planView.getPrintPreferredScale(LengthUnit.inchToCentimeter((float)pageFormat.getImageableWidth() / 72),
+              LengthUnit.inchToCentimeter((float)pageFormat.getImageableHeight() / 72));
+          planScale = "1/" + Math.round(1 / preferredScale);
+        }
         if (page == 0) {
           this.printDate = new Date();
         }
@@ -286,9 +280,9 @@ public class HomePrintableComponent extends JComponent implements Printable {
              homeName, ContentManager.ContentType.SWEET_HOME_3D);
         Object [] variableValues = new Object [] {
             pageNumber, pageCount, planScale, this.printDate, homePresentationName, homeName, levelName};
-        
+
         // Create header text
-        String headerFormat = homePrint.getHeaderFormat();      
+        String headerFormat = homePrint.getHeaderFormat();
         if (headerFormat != null) {
           header = Variable.getMessageFormat(headerFormat).format(variableValues).trim();
           if (header.length() > 0) {
@@ -300,7 +294,7 @@ public class HomePrintableComponent extends JComponent implements Printable {
             header = null;
           }
         }
-        
+
         // Create footer text
         String footerFormat = homePrint.getFooterFormat();
         if (footerFormat != null) {
@@ -314,47 +308,47 @@ public class HomePrintableComponent extends JComponent implements Printable {
           }
         }
       }
-      
+
       // Update page format paper margins depending on paper orientation
       Paper paper = pageFormat.getPaper();
       switch (pageFormat.getOrientation()) {
         case PageFormat.PORTRAIT:
-          paper.setImageableArea(paper.getImageableX(), imageableY, 
+          paper.setImageableArea(paper.getImageableX(), imageableY,
               paper.getImageableWidth(), imageableHeight);
           break;
         case PageFormat.LANDSCAPE :
-          paper.setImageableArea(paper.getWidth() - (imageableHeight + imageableY), 
-              paper.getImageableY(), 
+          paper.setImageableArea(paper.getWidth() - (imageableHeight + imageableY),
+              paper.getImageableY(),
               imageableHeight, paper.getImageableHeight());
         case PageFormat.REVERSE_LANDSCAPE:
-          paper.setImageableArea(imageableY, paper.getImageableY(), 
+          paper.setImageableArea(imageableY, paper.getImageableY(),
               imageableHeight, paper.getImageableHeight());
           break;
       }
       pageFormat.setPaper(paper);
-      
+
       if (clipBounds == null) {
-        g2D.clipRect((int)pageFormat.getImageableX(), (int)pageFormat.getImageableY(), 
+        g2D.clipRect((int)pageFormat.getImageableX(), (int)pageFormat.getImageableY(),
             (int)pageFormat.getImageableWidth(), (int)pageFormat.getImageableHeight());
-      } else {  
-        g2D.clipRect(clipBounds.x, (int)pageFormat.getImageableY(), 
+      } else {
+        g2D.clipRect(clipBounds.x, (int)pageFormat.getImageableY(),
             clipBounds.width, (int)pageFormat.getImageableHeight());
       }
     }
-    
+
     View furnitureView = this.controller.getFurnitureController().getView();
-    if (furnitureView != null 
+    if (furnitureView != null
         && (homePrint == null || homePrint.isFurniturePrinted())) {
-      FurnitureTable furnitureTable = null;
-      final FurnitureTable.FurnitureFilter furnitureFilter;
-      if (furnitureView instanceof FurnitureTable
+      FurnitureView filteredFurnitureView = null;
+      final FurnitureView.FurnitureFilter furnitureFilter;
+      if (furnitureView instanceof FurnitureView
           && (homePrint == null
               || homePrint.isPlanPrinted()
               || homePrint.isView3DPrinted())) {
         final Level selectedLevel = home.getSelectedLevel();
-        furnitureTable = (FurnitureTable)furnitureView;
-        furnitureFilter = furnitureTable.getFurnitureFilter();
-        furnitureTable.setFurnitureFilter(new FurnitureTable.FurnitureFilter() {
+        filteredFurnitureView = (FurnitureView)furnitureView;
+        furnitureFilter = filteredFurnitureView.getFurnitureFilter();
+        filteredFurnitureView.setFurnitureFilter(new FurnitureView.FurnitureFilter() {
             public boolean include(Home home, HomePieceOfFurniture piece) {
               // Print only furniture at selected level when the plan or the 3D view is printed
               return (furnitureFilter == null || furnitureFilter.include(home, piece))
@@ -365,11 +359,11 @@ public class HomePrintableComponent extends JComponent implements Printable {
       } else {
         furnitureFilter = null;
       }
-      // Try to print next furniture view page      
+      // Try to print next furniture view page
       pageExists = ((Printable)furnitureView).print(g2D, pageFormat, page);
-      if (furnitureTable != null) {
+      if (filteredFurnitureView != null) {
         // Restore previous filter
-        ((FurnitureTable)furnitureView).setFurnitureFilter(furnitureFilter);
+        filteredFurnitureView.setFurnitureFilter(furnitureFilter);
       }
       if (pageExists == PAGE_EXISTS
           && !this.printablePages.contains(page)) {
@@ -377,8 +371,8 @@ public class HomePrintableComponent extends JComponent implements Printable {
         this.furniturePageCount++;
       }
     }
-    if (pageExists == NO_SUCH_PAGE 
-        && planView != null 
+    if (pageExists == NO_SUCH_PAGE
+        && planView != null
         && (homePrint == null || homePrint.isPlanPrinted())) {
       // Try to print next plan view page
       pageExists = ((Printable)planView).print(g2D, pageFormat, page - this.furniturePageCount);
@@ -398,7 +392,7 @@ public class HomePrintableComponent extends JComponent implements Printable {
         this.printablePages.add(page);
       }
     }
-    
+
     // Print header and footer
     if (pageExists == PAGE_EXISTS) {
       g2D.setTransform(oldTransform);
@@ -421,8 +415,8 @@ public class HomePrintableComponent extends JComponent implements Printable {
         fixedFooterPageLabel.print(g2D);
         g2D.translate(-xFixedFooter, -yFixedFooter);
       }
-    }  
-    pageFormat.setPaper(oldPaper);    
+    }
+    pageFormat.setPaper(oldPaper);
     return pageExists;
   }
 
@@ -436,10 +430,10 @@ public class HomePrintableComponent extends JComponent implements Printable {
     double maxSize = Math.max(pageFormat.getWidth(), pageFormat.getHeight());
     Insets insets = getInsets();
     int maxPreferredSize = Math.round(400 * SwingTools.getResolutionScale());
-    return new Dimension((int)(pageFormat.getWidth() / maxSize * maxPreferredSize) + insets.left + insets.right, 
+    return new Dimension((int)(pageFormat.getWidth() / maxSize * maxPreferredSize) + insets.left + insets.right,
         (int)(pageFormat.getHeight() / maxSize * maxPreferredSize) + insets.top + insets.bottom);
   }
-  
+
   /**
    * Paints the current page.
    */
@@ -458,7 +452,7 @@ public class HomePrintableComponent extends JComponent implements Printable {
       throw new RuntimeException(ex);
     }
   }
-  
+
   /**
    * Sets the page currently painted by this component.
    */
@@ -468,7 +462,7 @@ public class HomePrintableComponent extends JComponent implements Printable {
       repaint();
     }
   }
-  
+
   /**
    * Returns the page currently painted by this component.
    */
@@ -477,7 +471,7 @@ public class HomePrintableComponent extends JComponent implements Printable {
   }
 
   /**
-   * Returns the page count of the home printed by this component. 
+   * Returns the page count of the home printed by this component.
    */
   public int getPageCount() {
     if (this.pageCount == -1) {
@@ -485,7 +479,7 @@ public class HomePrintableComponent extends JComponent implements Printable {
       BufferedImage dummyImage = new BufferedImage(1, 1, BufferedImage.TYPE_INT_RGB);
       Graphics dummyGraphics = dummyImage.getGraphics();
       // Count pages by printing in a dummy image
-      this.pageCount = 0; 
+      this.pageCount = 0;
       try {
         while (print(dummyGraphics, pageFormat, this.pageCount) == Printable.PAGE_EXISTS) {
           this.pageCount++;
@@ -521,8 +515,8 @@ public class HomePrintableComponent extends JComponent implements Printable {
       }
       Paper paper = new Paper();
       paper.setSize(homePrint.getPaperWidth(), homePrint.getPaperHeight());
-      paper.setImageableArea(homePrint.getPaperLeftMargin(), homePrint.getPaperTopMargin(), 
-          homePrint.getPaperWidth() - homePrint.getPaperLeftMargin() - homePrint.getPaperRightMargin(), 
+      paper.setImageableArea(homePrint.getPaperLeftMargin(), homePrint.getPaperTopMargin(),
+          homePrint.getPaperWidth() - homePrint.getPaperLeftMargin() - homePrint.getPaperRightMargin(),
           homePrint.getPaperHeight() - homePrint.getPaperTopMargin() - homePrint.getPaperBottomMargin());
       pageFormat.setPaper(paper);
       pageFormat = printerJob.validatePage(pageFormat);
