@@ -64,7 +64,7 @@ import com.eteks.sweethome3d.viewcontroller.View;
  */
 public class LevelPanel extends JPanel implements DialogView {
   private final LevelController controller;
-  private NullableCheckBox      viewableCheckBox;         
+  private NullableCheckBox      viewableCheckBox;
   private JLabel                nameLabel;
   private JTextField            nameTextField;
   private JLabel                elevationLabel;
@@ -80,7 +80,7 @@ public class LevelPanel extends JPanel implements DialogView {
   private String                dialogTitle;
 
   /**
-   * Creates a panel that displays home levels data according to the units 
+   * Creates a panel that displays home levels data according to the units
    * set in <code>preferences</code>.
    * @param preferences user preferences
    * @param controller the controller of this panel
@@ -97,14 +97,14 @@ public class LevelPanel extends JPanel implements DialogView {
   /**
    * Creates and initializes components and spinners model.
    */
-  private void createComponents(final UserPreferences preferences, 
+  private void createComponents(final UserPreferences preferences,
                                 final LevelController controller) {
-    // Get unit name matching current unit 
+    // Get unit name matching current unit
     String unitName = preferences.getLengthUnit().getName();
 
     if (controller.isPropertyEditable(LevelController.Property.VIEWABLE)) {
       // Create viewable check box bound to VIEWABLE controller property
-      this.viewableCheckBox = new NullableCheckBox(SwingTools.getLocalizedLabelText(preferences, 
+      this.viewableCheckBox = new NullableCheckBox(SwingTools.getLocalizedLabelText(preferences,
           LevelPanel.class, "viewableCheckBox.text"));
       this.viewableCheckBox.setNullable(controller.getViewable() == null);
       this.viewableCheckBox.setValue(controller.getViewable());
@@ -113,7 +113,7 @@ public class LevelPanel extends JPanel implements DialogView {
             controller.setViewable(viewableCheckBox.getValue());
           }
         });
-      controller.addPropertyChangeListener(LevelController.Property.VIEWABLE, 
+      controller.addPropertyChangeListener(LevelController.Property.VIEWABLE,
           new PropertyChangeListener() {
               public void propertyChange(PropertyChangeEvent ev) {
                 viewableCheckBox.setValue(controller.getViewable());
@@ -137,7 +137,7 @@ public class LevelPanel extends JPanel implements DialogView {
       this.nameTextField.getDocument().addDocumentListener(new DocumentListener() {
           public void changedUpdate(DocumentEvent ev) {
             controller.removePropertyChangeListener(LevelController.Property.NAME, nameChangeListener);
-            String name = nameTextField.getText(); 
+            String name = nameTextField.getText();
             if (name == null || name.trim().length() == 0) {
               controller.setName(null);
             } else {
@@ -145,23 +145,23 @@ public class LevelPanel extends JPanel implements DialogView {
             }
             controller.addPropertyChangeListener(LevelController.Property.NAME, nameChangeListener);
           }
-    
+
           public void insertUpdate(DocumentEvent ev) {
             changedUpdate(ev);
           }
-    
+
           public void removeUpdate(DocumentEvent ev) {
             changedUpdate(ev);
           }
         });
     }
-        
+
     final float maximumLength = preferences.getLengthUnit().getMaximumLength();
     if (controller.isPropertyEditable(LevelController.Property.ELEVATION)) {
       // Create elevation label and its spinner bound to ELEVATION controller property
-      this.elevationLabel = new JLabel(SwingTools.getLocalizedLabelText(preferences, 
+      this.elevationLabel = new JLabel(SwingTools.getLocalizedLabelText(preferences,
           LevelPanel.class, "elevationLabel.text", unitName));
-      final NullableSpinner.NullableSpinnerLengthModel elevationSpinnerModel = 
+      final NullableSpinner.NullableSpinnerLengthModel elevationSpinnerModel =
           new NullableSpinner.NullableSpinnerLengthModel(preferences, -1000f, preferences.getLengthUnit().getMaximumElevation());
       this.elevationSpinner = new NullableSpinner(elevationSpinnerModel);
       elevationSpinnerModel.setNullable(controller.getElevation() == null);
@@ -172,27 +172,27 @@ public class LevelPanel extends JPanel implements DialogView {
             elevationSpinnerModel.setLength((Float)ev.getNewValue());
           }
         };
-      controller.addPropertyChangeListener(LevelController.Property.ELEVATION, 
+      controller.addPropertyChangeListener(LevelController.Property.ELEVATION,
           elevationChangeListener);
       elevationSpinnerModel.addChangeListener(new ChangeListener() {
           public void stateChanged(ChangeEvent ev) {
-            controller.removePropertyChangeListener(LevelController.Property.ELEVATION, 
+            controller.removePropertyChangeListener(LevelController.Property.ELEVATION,
                 elevationChangeListener);
             controller.setElevation(elevationSpinnerModel.getLength());
             setFloorThicknessEnabled(controller);
             setElevationIndexButtonsEnabled(controller);
-            controller.addPropertyChangeListener(LevelController.Property.ELEVATION, 
+            controller.addPropertyChangeListener(LevelController.Property.ELEVATION,
                 elevationChangeListener);
           }
         });
     }
-    
+
     final float minimumLength = preferences.getLengthUnit().getMinimumLength();
     if (controller.isPropertyEditable(LevelController.Property.FLOOR_THICKNESS)) {
       // Create floor thickness label and its spinner bound to FLOOR_THICKNESS controller property
-      this.floorThicknessLabel = new JLabel(SwingTools.getLocalizedLabelText(preferences, 
+      this.floorThicknessLabel = new JLabel(SwingTools.getLocalizedLabelText(preferences,
           LevelPanel.class, "floorThicknessLabel.text", unitName));
-      final NullableSpinner.NullableSpinnerLengthModel floorThicknessSpinnerModel = 
+      final NullableSpinner.NullableSpinnerLengthModel floorThicknessSpinnerModel =
           new NullableSpinner.NullableSpinnerLengthModel(preferences, minimumLength, maximumLength / 10);
       this.floorThicknessSpinner = new NullableSpinner(floorThicknessSpinnerModel);
       final PropertyChangeListener floorThicknessChangeListener = new PropertyChangeListener() {
@@ -213,12 +213,12 @@ public class LevelPanel extends JPanel implements DialogView {
         });
       setFloorThicknessEnabled(controller);
     }
-    
+
     if (controller.isPropertyEditable(LevelController.Property.HEIGHT)) {
       // Create floor thickness label and its spinner bound to HEIGHT controller property
-      this.heightLabel = new JLabel(SwingTools.getLocalizedLabelText(preferences, 
+      this.heightLabel = new JLabel(SwingTools.getLocalizedLabelText(preferences,
           LevelPanel.class, "heightLabel.text", unitName));
-      final NullableSpinner.NullableSpinnerLengthModel heightSpinnerModel = 
+      final NullableSpinner.NullableSpinnerLengthModel heightSpinnerModel =
           new NullableSpinner.NullableSpinnerLengthModel(preferences, minimumLength, maximumLength);
       this.heightSpinner = new NullableSpinner(heightSpinnerModel);
       final PropertyChangeListener heightChangeListener = new PropertyChangeListener() {
@@ -238,7 +238,7 @@ public class LevelPanel extends JPanel implements DialogView {
           }
         });
     }
-    
+
     if (controller.isPropertyEditable(LevelController.Property.ELEVATION_INDEX)) {
       this.increaseElevationIndexButton = new JButton(new ResourceAction(preferences, LevelPanel.class, "INCREASE_ELEVATION_INDEX") {
           @Override
@@ -256,8 +256,8 @@ public class LevelPanel extends JPanel implements DialogView {
         });
       setElevationIndexButtonsEnabled(controller);
     }
-    
-    this.levelsSummaryLabel = new JLabel(SwingTools.getLocalizedLabelText(preferences, 
+
+    this.levelsSummaryLabel = new JLabel(SwingTools.getLocalizedLabelText(preferences,
         LevelPanel.class, "levelsSummaryLabel.text", unitName));
     final String [] columnNames = {
          SwingTools.getLocalizedLabelText(preferences, LevelPanel.class, "nameColumn"),
@@ -271,7 +271,7 @@ public class LevelPanel extends JPanel implements DialogView {
       this.levelsSummaryTable.setRowHeight(Math.round(this.levelsSummaryTable.getRowHeight() * resolutionScale));
     }
     // Display lengths according to the current length unit
-    TableColumnModel columnModel = this.levelsSummaryTable.getColumnModel();    
+    TableColumnModel columnModel = this.levelsSummaryTable.getColumnModel();
     columnModel.getColumn(0).setCellRenderer(new DefaultTableCellRenderer() {
         @Override
         public Component getTableCellRendererComponent(JTable table, Object value, boolean isSelected, boolean hasFocus,
@@ -281,8 +281,8 @@ public class LevelPanel extends JPanel implements DialogView {
         }
       });
     TableCellRenderer lengthRenderer = new DefaultTableCellRenderer() {
-        public Component getTableCellRendererComponent(JTable table, Object value, 
-                                                       boolean isSelected, boolean hasFocus, 
+        public Component getTableCellRendererComponent(JTable table, Object value,
+                                                       boolean isSelected, boolean hasFocus,
                                                        int row, int column) {
           if (value != null) {
             value = preferences.getLengthUnit().getFormat().format((Float)value);
@@ -310,45 +310,45 @@ public class LevelPanel extends JPanel implements DialogView {
               }
             });
         }
-        
+
         public void setSelectionInterval(int index0, int index1) {
         }
-        
+
         public void setLeadSelectionIndex(int index) {
         }
-        
+
         public void setAnchorSelectionIndex(int index) {
         }
-        
+
         public boolean isSelectionEmpty() {
           return controller.getSelectedLevelIndex() != null;
         }
-        
+
         public boolean isSelectedIndex(int index) {
           // Levels are listed in the table in reverse order
           return controller.getSelectedLevelIndex() == levelsSummaryTable.getRowCount() - index - 1;
         }
-        
+
         public void insertIndexInterval(int index, int length, boolean before) {
         }
       });
     this.levelsSummaryTable.setFocusable(false);
     this.levelsSummaryTable.addAncestorListener(new AncestorListener() {
         public void ancestorAdded(AncestorEvent ev) {
-          scrollToSelectedLevel(controller);  
-          ev.getComponent().removeAncestorListener(this);        
+          scrollToSelectedLevel(controller);
+          ev.getComponent().removeAncestorListener(this);
         }
-        
+
         public void ancestorRemoved(AncestorEvent ev) {
         }
-        
+
         public void ancestorMoved(AncestorEvent ev) {
         }
       });
-    
+
     this.dialogTitle = preferences.getLocalizedString(LevelPanel.class, "level.title");
   }
-  
+
   private void setFloorThicknessEnabled(final LevelController controller) {
     Integer selectedLevelIndex = controller.getSelectedLevelIndex();
     if (this.floorThicknessSpinner != null && selectedLevelIndex != null) {
@@ -359,7 +359,7 @@ public class LevelPanel extends JPanel implements DialogView {
   }
 
   /**
-   * Ensures selected level is visible. 
+   * Ensures selected level is visible.
    */
   private void scrollToSelectedLevel(final LevelController controller) {
     Integer selectedLevelIndex = controller.getSelectedLevelIndex();
@@ -371,7 +371,7 @@ public class LevelPanel extends JPanel implements DialogView {
   }
 
   /**
-   * Updates elevation index buttons. 
+   * Updates elevation index buttons.
    */
   private void setElevationIndexButtonsEnabled(final LevelController controller) {
     Integer selectedLevelIndex = controller.getSelectedLevelIndex();
@@ -418,92 +418,93 @@ public class LevelPanel extends JPanel implements DialogView {
       }
     }
   }
-  
+
   /**
-   * Layouts panel components in panel with their labels. 
+   * Layouts panel components in panel with their labels.
    */
-  private void layoutComponents(UserPreferences preferences, 
+  private void layoutComponents(UserPreferences preferences,
                                 final LevelController controller) {
-    int labelAlignment = OperatingSystem.isMacOSX() 
+    int labelAlignment = OperatingSystem.isMacOSX()
         ? GridBagConstraints.LINE_END
         : GridBagConstraints.LINE_START;
-    Insets labelInsets = new Insets(0, 0, 5, 5);
-    Insets rightComponentInsets = new Insets(0, 0, 5, 0);
+    int standardGap = Math.round(5 * SwingTools.getResolutionScale());
+    Insets labelInsets = new Insets(0, 0, standardGap, standardGap);
+    Insets rightComponentInsets = new Insets(0, 0, standardGap, 0);
     if (this.viewableCheckBox != null) {
-      // First row    
+      // First row
       add(this.viewableCheckBox, new GridBagConstraints(
-          1, 0, 2, 1, 0, 0, GridBagConstraints.LINE_START, 
-          GridBagConstraints.NONE, new Insets(0, -4, 5, 0), 0, 0));
+          1, 0, 2, 1, 0, 0, GridBagConstraints.LINE_START,
+          GridBagConstraints.NONE, new Insets(0, -4, standardGap, 0), 0, 0));
     }
     if (this.nameLabel != null) {
       // Second row
       add(this.nameLabel, new GridBagConstraints(
-          0, 1, 1, 1, 0, 0, labelAlignment, 
+          0, 1, 1, 1, 0, 0, labelAlignment,
           GridBagConstraints.NONE, labelInsets, 0, 0));
       add(this.nameTextField, new GridBagConstraints(
-          1, 1, 2, 1, 0, 0, GridBagConstraints.LINE_START, 
+          1, 1, 2, 1, 0, 0, GridBagConstraints.LINE_START,
           GridBagConstraints.HORIZONTAL, rightComponentInsets, 0, 0));
     }
     if (this.elevationLabel != null) {
       // Third row
       add(this.elevationLabel, new GridBagConstraints(
-          0, 2, 1, 1, 0, 0, labelAlignment, 
+          0, 2, 1, 1, 0, 0, labelAlignment,
           GridBagConstraints.NONE, labelInsets, 0, 0));
       add(this.elevationSpinner, new GridBagConstraints(
-          1, 2, 1, 1, 0.1, 0, GridBagConstraints.LINE_START, 
+          1, 2, 1, 1, 0.1, 0, GridBagConstraints.LINE_START,
           GridBagConstraints.HORIZONTAL, rightComponentInsets, -15, 0));
       add(new JLabel(), new GridBagConstraints(
-          2, 2, 1, 1, 0.2, 0, GridBagConstraints.LINE_START, 
+          2, 2, 1, 1, 0.2, 0, GridBagConstraints.LINE_START,
           GridBagConstraints.HORIZONTAL, rightComponentInsets, 0, 0));
     }
     if (this.floorThicknessLabel != null) {
       // Forth row
       add(this.floorThicknessLabel, new GridBagConstraints(
-          0, 3, 1, 1, 0, 0, labelAlignment, 
+          0, 3, 1, 1, 0, 0, labelAlignment,
           GridBagConstraints.NONE, labelInsets, 0, 0));
       add(this.floorThicknessSpinner, new GridBagConstraints(
-          1, 3, 1, 1, 0.1, 0, GridBagConstraints.LINE_START, 
+          1, 3, 1, 1, 0.1, 0, GridBagConstraints.LINE_START,
           GridBagConstraints.HORIZONTAL, rightComponentInsets, -15, 0));
       add(new JLabel(), new GridBagConstraints(
-          2, 3, 1, 1, 0.2, 0, GridBagConstraints.LINE_START, 
+          2, 3, 1, 1, 0.2, 0, GridBagConstraints.LINE_START,
           GridBagConstraints.HORIZONTAL, rightComponentInsets, 0, 0));
     }
     if (this.heightLabel != null) {
       // Fifth row
       add(this.heightLabel, new GridBagConstraints(
-          0, 4, 1, 1, 0, 0, labelAlignment, 
-          GridBagConstraints.NONE, new Insets(0, 0, 0, 5), 0, 0));
+          0, 4, 1, 1, 0, 0, labelAlignment,
+          GridBagConstraints.NONE, new Insets(0, 0, 0, standardGap), 0, 0));
       add(this.heightSpinner, new GridBagConstraints(
-          1, 4, 1, 1, 0.1, 0, GridBagConstraints.LINE_START, 
+          1, 4, 1, 1, 0.1, 0, GridBagConstraints.LINE_START,
           GridBagConstraints.HORIZONTAL, new Insets(0, 0, 0, 0), -15, 0));
       add(new JLabel(), new GridBagConstraints(
-          2, 4, 1, 1, 0.2, 0, GridBagConstraints.LINE_START, 
+          2, 4, 1, 1, 0.2, 0, GridBagConstraints.LINE_START,
           GridBagConstraints.HORIZONTAL, rightComponentInsets, 0, 0));
     }
     add(new JSeparator(), new GridBagConstraints(
-        0, 5, 4, 1, 0, 0, GridBagConstraints.LINE_START, 
-        GridBagConstraints.HORIZONTAL, new Insets(5, 0, 5, 0), 0, 0));
+        0, 5, 4, 1, 0, 0, GridBagConstraints.LINE_START,
+        GridBagConstraints.HORIZONTAL, new Insets(standardGap, 0, standardGap, 0), 0, 0));
     add(this.levelsSummaryLabel, new GridBagConstraints(
-        0, 6, 3, 1, 0, 0, GridBagConstraints.LINE_START, 
-        GridBagConstraints.NONE, new Insets(0, 0, 5, 0), 0, 0));
+        0, 6, 3, 1, 0, 0, GridBagConstraints.LINE_START,
+        GridBagConstraints.NONE, new Insets(0, 0, standardGap, 0), 0, 0));
     JScrollPane levelsSummaryPane = new JScrollPane(this.levelsSummaryTable);
-    levelsSummaryPane.setPreferredSize(new Dimension(Math.round(320 * SwingTools.getResolutionScale()), 
+    levelsSummaryPane.setPreferredSize(new Dimension(Math.round(320 * SwingTools.getResolutionScale()),
         this.levelsSummaryTable.getTableHeader().getPreferredSize().height + this.levelsSummaryTable.getRowHeight() * 8 + 1));
     add(levelsSummaryPane, new GridBagConstraints(
-        0, 7, 3, 2, 1, 1, GridBagConstraints.CENTER, 
+        0, 7, 3, 2, 1, 1, GridBagConstraints.CENTER,
         GridBagConstraints.BOTH, new Insets(0, 0, 0, 0), 0, 0));
     // Add elevation index buttons at right of the levels table
     add(this.increaseElevationIndexButton, new GridBagConstraints(
-        3, 7, 1, 1, 0, 0.5, GridBagConstraints.SOUTH, 
-        GridBagConstraints.NONE, new Insets(0, 5, 2, 0), 0, 0));
+        3, 7, 1, 1, 0, 0.5, GridBagConstraints.SOUTH,
+        GridBagConstraints.NONE, new Insets(0, standardGap, 2, 0), 0, 0));
     add(this.decreaseElevationIndexButton, new GridBagConstraints(
-        3, 8, 1, 1, 0, 0.5, GridBagConstraints.NORTH, 
-        GridBagConstraints.NONE, new Insets(2, 5, 0, 0), 0, 0));
-    
+        3, 8, 1, 1, 0, 0.5, GridBagConstraints.NORTH,
+        GridBagConstraints.NONE, new Insets(2, standardGap, 0, 0), 0, 0));
+
     if (!OperatingSystem.isMacOSX()) {
       // Make buttons square
       Dimension preferredSize = this.increaseElevationIndexButton.getPreferredSize();
-      preferredSize.width = 
+      preferredSize.width =
       preferredSize.height = preferredSize.height + 4;
       this.increaseElevationIndexButton.setPreferredSize(preferredSize);
       this.decreaseElevationIndexButton.setPreferredSize(preferredSize);
@@ -511,17 +512,17 @@ public class LevelPanel extends JPanel implements DialogView {
   }
 
   /**
-   * Displays this panel in a modal dialog box. 
+   * Displays this panel in a modal dialog box.
    */
   public void displayView(View parentView) {
-    if (SwingTools.showConfirmDialog((JComponent)parentView, 
+    if (SwingTools.showConfirmDialog((JComponent)parentView,
             this, this.dialogTitle, this.nameTextField) == JOptionPane.OK_OPTION) {
       this.controller.modifyLevels();
     }
   }
 
   /**
-   * The model of the table used to show levels information. 
+   * The model of the table used to show levels information.
    */
   private static final class LevelsTableModel extends AbstractTableModel {
     private Level  [] levels;
@@ -553,14 +554,14 @@ public class LevelPanel extends JPanel implements DialogView {
         case 1 : return level.getElevation();
         case 2 :
           if (level.getElevation() == this.levels [0].getElevation()) {
-            return null; // Don't display floor thickness of first levels 
+            return null; // Don't display floor thickness of first levels
           } else {
             return level.getFloorThickness();
           }
         case 3 : return level.getHeight();
         case 4 :
           // Use not visible 5th column to retrieve viewable information
-          return level.isViewable(); 
+          return level.isViewable();
       }
       return null;
     }
