@@ -20,6 +20,7 @@
 package com.eteks.sweethome3d.swing;
 
 import java.awt.Component;
+import java.awt.ComponentOrientation;
 import java.awt.Dimension;
 import java.awt.Graphics;
 import java.awt.Graphics2D;
@@ -37,6 +38,7 @@ import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Locale;
 
 import javax.swing.ButtonGroup;
 import javax.swing.DefaultComboBoxModel;
@@ -46,6 +48,7 @@ import javax.swing.JButton;
 import javax.swing.JComboBox;
 import javax.swing.JComponent;
 import javax.swing.JDialog;
+import javax.swing.JEditorPane;
 import javax.swing.JFormattedTextField;
 import javax.swing.JLabel;
 import javax.swing.JList;
@@ -119,7 +122,7 @@ public class WallPanel extends JPanel implements DialogView {
   private JSpinner             thicknessSpinner;
   private JLabel               arcExtentLabel;
   private JSpinner             arcExtentSpinner;
-  private JLabel               wallOrientationLabel;
+  private JEditorPane          wallOrientationLabel;
   private String               dialogTitle;
 
   /**
@@ -765,11 +768,13 @@ public class WallPanel extends JPanel implements DialogView {
       });
 
     // wallOrientationLabel shows an HTML explanation of wall orientation with an image URL in resource
-    this.wallOrientationLabel = new JLabel(preferences.getLocalizedString(
+    this.wallOrientationLabel = new JEditorPane("text/html", preferences.getLocalizedString(
             WallPanel.class, "wallOrientationLabel.text",
-            new ResourceURLContent(WallPanel.class, "resources/wallOrientation.png").getURL()),
-        JLabel.CENTER);
+            new ResourceURLContent(WallPanel.class, "resources/wallOrientation.png").getURL()).replace("<html>", "<html><center>"));
+    this.wallOrientationLabel.setEditable(false);
+    this.wallOrientationLabel.setOpaque(false);
     // Use same font for label as tooltips
+    this.wallOrientationLabel.putClientProperty(JEditorPane.HONOR_DISPLAY_PROPERTIES, Boolean.TRUE);
     this.wallOrientationLabel.setFont(UIManager.getFont("ToolTip.font"));
 
     this.dialogTitle = preferences.getLocalizedString(WallPanel.class, "wall.title");
@@ -1184,10 +1189,10 @@ public class WallPanel extends JPanel implements DialogView {
       JOptionPane optionPane = new JOptionPane(this,
           JOptionPane.PLAIN_MESSAGE, JOptionPane.OK_CANCEL_OPTION);
       JComponent parentComponent = SwingUtilities.getRootPane((JComponent)parentView);
-      if (parentView != null) {
-        optionPane.setComponentOrientation(parentComponent.getComponentOrientation());
-      }
       JDialog dialog = optionPane.createDialog(parentComponent, this.dialogTitle);
+      dialog.applyComponentOrientation(parentComponent != null
+          ? parentComponent.getComponentOrientation()
+          : ComponentOrientation.getOrientation(Locale.getDefault()));
       Dimension screenSize = getToolkit().getScreenSize();
       Insets screenInsets = getToolkit().getScreenInsets(getGraphicsConfiguration());
       // Check dialog isn't too high
