@@ -130,6 +130,13 @@ public interface ViewFactory {
   public abstract DialogView createRoomView(UserPreferences preferences,
                                             RoomController roomController);
   
+  /**
+   * Returns a new view that edits polyline values.
+   * @since 5.0
+   */
+  public abstract DialogView createPolylineView(UserPreferences preferences,
+                                                PolylineController polylineController);
+
   /**
    * Returns a new view that edits label values.
    */
@@ -161,6 +168,12 @@ public interface ViewFactory {
   public abstract TextureChoiceView createTextureChoiceView(UserPreferences preferences,
                                                      TextureChoiceController textureChoiceController);
 
+  /**
+   * Returns a new view that edits the baseboard of its controller.  
+   */
+  public abstract View createBaseboardChoiceView(UserPreferences preferences,
+                                                 BaseboardChoiceController baseboardChoiceController);
+
   /**
    * Returns a new view that edits the materials of its controller.  
    */
